
# Slot: companies




URI: [ks:dataset__companies](https://w3id.org/linkml/tests/kitchen_sink/dataset__companies)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Company](Company.md)

## Parents


## Children


## Used by

 * [Dataset](Dataset.md)
